@@ -45,7 +45,7 @@ namespace zypp {
     {}
 
 
-    ExternalProgram::ExternalProgram( std::string commandline,
+    ExternalProgram::ExternalProgram( const std::string& commandline,
                                       Stderr_Disposition stderr_disp,
                                       bool use_pty,
                                       int stderr_fd,
@@ -236,7 +236,7 @@ namespace zypp {
       if ( usePty )
       {
 
-        int master_tty,	slave_tty;		// fds for pair of ttys
+        int master_tty = 0,	slave_tty = 0;		// fds for pair of ttys
 
         // Create pair of ttys
         DBG << "Using ttys for communication with " << argv[0] << endl;
@@ -344,6 +344,15 @@ namespace zypp {
       }
     }
 
+    bool ExternalProgram::waitForExit(std::optional<uint64_t> timeout)
+    {
+      if ( !_backend ) {
+        // no backend means no running progress, return true
+        return true;
+      }
+      return _backend->waitForExit( timeout );
+    }
+
     int
     ExternalProgram::close()
     {
@@ -366,17 +375,18 @@ namespace zypp {
           do
           {
             /* Watch inputFile to see when it has input. */
-            fd_set rfds;
-            FD_ZERO( &rfds );
-            FD_SET( inputfileFd, &rfds );
+            GPollFD rfd;
+            rfd.fd = inputfileFd;
+            rfd.events =  G_IO_IN | G_IO_HUP | G_IO_ERR;
+            rfd.revents = 0;
 
-            /* Wait up to 1 seconds. */
-            struct timeval tv;
-            tv.tv_sec  = (delay < 0 ? 1 : 0);
-            tv.tv_usec = (delay < 0 ? 0 : delay*100000);
+            // each try increases our wait by 0.1 seconds, until we have
+            // 1 sec max timout.
+            gint timeout = delay < 0 ? 1000 : delay*100;
             if ( delay >= 0 && ++delay > 9 )
               delay = -1;
-            int retval = select( inputfileFd+1, &rfds, NULL, NULL, &tv );
+
+            int retval = g_poll( &rfd, 1, timeout );
 
             if ( retval == -1 )
             {
@@ -419,7 +429,10 @@ namespace zypp {
     {
       if ( _backend && _backend->isRunning() )
       {
-        ::kill( _backend->pid(), SIGKILL);
+        if ( ::kill( _backend->pid(), SIGKILL) == -1 ) {
+          ERR << "Failed to kill PID " << _backend->pid() << " with error: " << Errno() << std::endl;
+          return false;
+        }
         close();
       }
       return true;
@@ -429,7 +442,10 @@ namespace zypp {
     {
       if ( _backend && _backend->isRunning()  )
       {
-        ::kill( _backend->pid(), sig );
+        if ( ::kill( _backend->pid(), sig ) == -1 ) {
+          ERR << "Failed to kill PID " << _backend->pid() << " with error: " << Errno() << std::endl;
+          return false;
+        }
       }
       return true;
     }
