@@ -18,6 +18,7 @@
 #include <stdexcept>
 #include <typeinfo>
 #include <type_traits>
+#include <utility>
 
 #include <zypp-core/base/Errno.h>
 
@@ -41,10 +42,10 @@ namespace zypp
       {}
 
       /** Ctor */
-      CodeLocation( const std::string & file_r,
-                    const std::string & func_r,
+      CodeLocation( std::string  file_r,
+                    std::string  func_r,
                     unsigned            line_r )
-      : _file( file_r ), _func( func_r ), _line( line_r )
+      : _file(std::move( file_r )), _func(std::move( func_r )), _line( line_r )
       {}
 
       /** Location as string */
@@ -147,10 +148,10 @@ namespace zypp
     friend std::ostream & operator<<( std::ostream & str, const Exception & obj );
 
   public:
-    typedef exception_detail::CodeLocation CodeLocation;
-    typedef std::list<std::string>         History;
-    typedef History::const_iterator        HistoryIterator;
-    typedef History::size_type             HistorySize;
+    using CodeLocation = exception_detail::CodeLocation;
+    using History = std::list<std::string>;
+    using HistoryIterator = History::const_iterator;
+    using HistorySize = History::size_type;
 
     /** Default ctor.
      * Use \ref ZYPP_THROW to throw exceptions.
@@ -177,7 +178,7 @@ namespace zypp
     Exception( std::string && msg_r, Exception && history_r );
 
     /** Dtor. */
-    virtual ~Exception() throw();
+    ~Exception() throw() override;
 
     /** Return CodeLocation. */
     const CodeLocation & where() const
@@ -220,6 +221,16 @@ namespace zypp
     /** \overload std::exception_ptr */
     void remember( std::exception_ptr old_r );
 
+    /** Remembering a plain string is most probably not wanted - we \ref addHistory.
+     * It would discards the old history and replace it with this string.
+     * If that's actually your intent, explicitly wrap it into an \ref Exception.
+     */
+    void remember( const std::string & msg_r )
+    { addHistory( msg_r ); }
+    /** \overload moving */
+    void remember( std::string && msg_r )
+    { addHistory( std::move(msg_r) ); }
+
     /** Add some message text to the history. */
     void addHistory( const std::string & msg_r );
     /** \overload moving */
@@ -281,9 +292,7 @@ namespace zypp
      /** Make a string from \a errno_r. */
     static std::string strErrno( int errno_r );
      /** Make a string from \a errno_r and \a msg_r. */
-    static std::string strErrno( int errno_r, const std::string & msg_r );
-    /** \overload moving */
-    static std::string strErrno( int errno_r, std::string && msg_r );
+    static std::string strErrno( int errno_r, std::string msg_r );
 
   public:
     /** Drop a logline on throw, catch or rethrow.
@@ -300,7 +309,7 @@ namespace zypp
     History              _history;
 
     /** Return message string. */
-    virtual const char * what() const throw()
+    const char * what() const throw() override
     { return _msg.c_str(); }
 
     /** Called by <tt>std::ostream & operator\<\<</tt>.
@@ -319,11 +328,11 @@ namespace zypp
   {
     /** SFINAE: Hide template signature unless \a TExcpt is derived from \ref Exception. */
     template<class TExcpt>
-    using EnableIfIsException = typename std::enable_if< std::is_base_of<Exception,TExcpt>::value, int>::type;
+    using EnableIfIsException = std::enable_if_t< std::is_base_of_v<Exception,TExcpt>, int>;
 
     /** SFINAE: Hide template signature if \a TExcpt is derived from  \ref Exception. */
     template<class TExcpt>
-    using EnableIfNotException = typename std::enable_if< !std::is_base_of<Exception,TExcpt>::value, int>::type;
+    using EnableIfNotException = std::enable_if_t< !std::is_base_of_v<Exception,TExcpt>, int>;
 
 
     /** Helper for \ref ZYPP_THROW( Exception ). */
@@ -384,25 +393,27 @@ namespace zypp
       throw;
     }
 
+    void do_ZYPP_RETHROW( const std::exception_ptr & excpt_r, const CodeLocation & where_r );
+
     /** Helper for \ref ZYPP_EXCPT_PTR( Exception ). */
     template<class TExcpt, EnableIfIsException<TExcpt> = 0>
-    std::exception_ptr do_ZYPP_EXCPT_PTR( const TExcpt & excpt_r, const CodeLocation & where_r );
+    std::exception_ptr do_ZYPP_EXCPT_PTR( TExcpt && excpt_r, const CodeLocation & where_r );
     template<class TExcpt, EnableIfIsException<TExcpt>>
-    std::exception_ptr do_ZYPP_EXCPT_PTR( const TExcpt & excpt_r, const CodeLocation & where_r )
+    std::exception_ptr do_ZYPP_EXCPT_PTR( TExcpt && excpt_r, const CodeLocation & where_r )
     {
       excpt_r.relocate( where_r );
-      Exception::log( excpt_r, where_r, "THROW:   " );
-      return std::make_exception_ptr( excpt_r );
+      Exception::log( excpt_r, where_r, "EXCPTR:   " );
+      return std::make_exception_ptr( std::forward<TExcpt>(excpt_r) );
     }
 
     /** Helper for \ref ZYPP_EXCPT_PTR( not Exception ). */
     template<class TExcpt, EnableIfNotException<TExcpt> = 0>
-    std::exception_ptr do_ZYPP_EXCPT_PTR( const TExcpt & excpt_r, const CodeLocation & where_r );
+    std::exception_ptr do_ZYPP_EXCPT_PTR( TExcpt && excpt_r, const CodeLocation & where_r );
     template<class TExcpt, EnableIfNotException<TExcpt>>
-    std::exception_ptr do_ZYPP_EXCPT_PTR( const TExcpt & excpt_r, const CodeLocation & where_r )
+    std::exception_ptr do_ZYPP_EXCPT_PTR( TExcpt && excpt_r, const CodeLocation & where_r )
     {
-      Exception::log( typeid(excpt_r).name(), where_r, "THROW:   " );
-      return std::make_exception_ptr( excpt_r );
+      Exception::log( typeid(excpt_r).name(), where_r, "EXCPTR:   " );
+      return std::make_exception_ptr( std::forward<TExcpt>(excpt_r) );
     }
 
 
