@@ -23,6 +23,7 @@
 #include <zypp-core/TriBool.h>
 #include <zypp-core/AutoDispose.h>
 
+#include <utility>
 #include <zypp-core/zyppng/io/Socket>
 #include <zypp-core/zyppng/io/SockAddr>
 #include <zypp-core/zyppng/base/EventLoop>
@@ -83,10 +84,12 @@ namespace zypp
   {
 
   public:
+    LogThread(const LogThread &) = delete;
+    LogThread(LogThread &&) = delete;
+    LogThread &operator=(const LogThread &) = delete;
+    LogThread &operator=(LogThread &&) = delete;
 
-    ~LogThread() {
-      stop();
-    }
+    ~LogThread() { stop(); }
 
     static LogThread &instance () {
       static LogThread t;
@@ -95,7 +98,7 @@ namespace zypp
 
     void setLineWriter ( boost::shared_ptr<log::LineWriter> writer ) {
       std::lock_guard lk( _lineWriterLock );
-      _lineWriter = writer;
+      _lineWriter = std::move(writer);
     }
 
     boost::shared_ptr<log::LineWriter> getLineWriter () {
@@ -132,8 +135,8 @@ namespace zypp
 
     void workerMain () {
 
-      // force the kernel to pick another thread to handle those signals
-      zyppng::blockSignalsForCurrentThread( { SIGTERM, SIGINT, SIGPIPE, } );
+      // force the kernel to pick another thread to handle signals
+      zyppng::blockAllSignalsForCurrentThread();
 
       zyppng::ThreadData::current().setName("Zypp-Log");
 
@@ -220,9 +223,12 @@ namespace zypp
       LogThread::instance();
     }
 
-    ~LogClient() {
-      ::close( _sockFD );
-    }
+    LogClient(const LogClient &) = delete;
+    LogClient(LogClient &&) = delete;
+    LogClient &operator=(const LogClient &) = delete;
+    LogClient &operator=(LogClient &&) = delete;
+
+    ~LogClient() { ::close(_sockFD); }
 
     /*!
      * Tries to connect to the log threads socket, returns true on success or
@@ -243,7 +249,7 @@ namespace zypp
     /*!
      * Sends a message to the log thread.
      */
-    void pushMessage ( std::string &&msg ) {
+    void pushMessage ( std::string msg ) {
       if ( inPushMessage ) {
         return;
       }
@@ -408,15 +414,21 @@ namespace zypp
 
       public:
         /** */
-        Loglinebuf( const std::string & group_r, LogLevel level_r )
-        : _group( group_r )
+        Loglinebuf( std::string  group_r, LogLevel level_r )
+        : _group(std::move( group_r ))
         , _level( level_r )
         , _file( "" )
         , _func( "" )
         , _line( -1 )
         {}
+
+        Loglinebuf(const Loglinebuf &) = default;
+        Loglinebuf(Loglinebuf &&) = default;
+        Loglinebuf &operator=(const Loglinebuf &) = default;
+        Loglinebuf &operator=(Loglinebuf &&) = default;
+
         /** */
-        ~Loglinebuf()
+        ~Loglinebuf() override
         {
           if ( !_buffer.empty() )
             writeout( "\n", 1 );
@@ -432,10 +444,10 @@ namespace zypp
 
       private:
         /** */
-        virtual std::streamsize xsputn( const char * s, std::streamsize n )
+        std::streamsize xsputn( const char * s, std::streamsize n ) override
         { return writeout( s, n ); }
         /** */
-        virtual int overflow( int ch = EOF )
+        int overflow( int ch = EOF ) override
         {
           if ( ch != EOF )
             {
@@ -492,6 +504,12 @@ namespace zypp
         : _mybuf( group_r, level_r )
         , _mystream( &_mybuf )
         {}
+
+        Loglinestream(const Loglinestream &) = delete;
+        Loglinestream(Loglinestream &&) = delete;
+        Loglinestream &operator=(const Loglinestream &) = delete;
+        Loglinestream &operator=(Loglinestream &&) = delete;
+
         /** */
         ~Loglinestream()
         { _mystream.flush(); }
@@ -543,8 +561,7 @@ namespace zypp
       struct LogControlImpl
       {
       public:
-        bool isExcessive() const
-        { return _excessive; }
+        bool isExcessive() const { return _excessive; }
 
         void excessive( bool onOff_r )
         { _excessive = onOff_r; }
@@ -668,9 +685,9 @@ namespace zypp
         }
 
       private:
-        typedef shared_ptr<Loglinestream>        StreamPtr;
-        typedef std::map<LogLevel,StreamPtr>     StreamSet;
-        typedef std::map<std::string,StreamSet>  StreamTable;
+        using StreamPtr = shared_ptr<Loglinestream>;
+        using StreamSet = std::map<LogLevel, StreamPtr>;
+        using StreamTable = std::map<std::string, StreamSet>;
         /** one streambuffer per group and level */
         StreamTable _streamtable;
         zyppng::Socket::Ptr _sock;
@@ -704,6 +721,11 @@ namespace zypp
 
       public:
 
+        LogControlImpl(const LogControlImpl &) = delete;
+        LogControlImpl(LogControlImpl &&) = delete;
+        LogControlImpl &operator=(const LogControlImpl &) = delete;
+        LogControlImpl &operator=(LogControlImpl &&) = delete;
+
         ~LogControlImpl()
         {
           logControlValidFlag() = 0;
