@@ -45,7 +45,7 @@ namespace zypp
     {
       StreamLineWriter( std::ostream & str_r ) : _str( &str_r ) {}
 
-      virtual void writeOut( const std::string & formated_r )
+      void writeOut( const std::string & formated_r ) override
       { (*_str) << formated_r << std::endl; }
 
       protected:
@@ -104,7 +104,7 @@ namespace zypp
 
 
       /** \see \ref log::LineWriter */
-      typedef log::LineWriter LineWriter;
+      using LineWriter = log::LineWriter;
 
       /** If you want to format loglines by yourself,
        *  derive from this, and overload \c format.
@@ -129,6 +129,13 @@ namespace zypp
       */
       void setLineFormater( const shared_ptr<LineFormater> & formater_r );
 
+      /*!
+       * Sets a special log mode that uses the ppid in the log output and always shows the
+       * thread name (if the default formatter is used). This is only used by internal zypp tools that directly want to log into the
+       * parents logfile.
+       */
+      void enableLogForwardingMode ( bool enable = true );
+
     public:
       /** Set path for the logfile.
        * Permission for logfiles is set to 0640 unless an explicit mode_t
@@ -155,6 +162,9 @@ namespace zypp
        */
       static void notifyFork();
 
+      /** will push a line to the logthread without formatting it */
+      void logRawLine ( std::string &&line );
+
     public:
       /** Get the current LineWriter */
       shared_ptr<LineWriter> getLineWriter() const;
