@@ -27,7 +27,7 @@
 
 ///////////////////////////////////////////////////////////////////
 namespace boost { namespace logic { class tribool; } }
-namespace zypp { typedef boost::logic::tribool TriBool; }
+namespace zypp { using TriBool = boost::logic::tribool; }
 ///////////////////////////////////////////////////////////////////
 
 ///////////////////////////////////////////////////////////////////
@@ -77,7 +77,7 @@ namespace zypp
    * \endcode
    *
    * This is where \ref C_Str can help. Constructible from \c std::string and \c char*,
-   * it \e reduces the \c std::string to it's \c char*. At the same time it converts
+   * it \e reduces the \c std::string to its \c char*. At the same, time it converts
    * \c (char*)0 into an \c "" string.
    *
    * \code
@@ -90,7 +90,7 @@ namespace zypp
   class C_Str
   {
     public:
-      typedef std::string::size_type size_type;
+      using size_type = std::string::size_type;
 
     public:
       C_Str()                            : _val( 0 ),             _sze( 0 ) {}
@@ -440,7 +440,7 @@ namespace zypp
       return return_r;
     }
 
-    /** Parse \c str into a bool if it's a legal \c true or \c false string; else \c indterminate. */
+    /** Parse \c str into a bool if it's a legal \c true or \c false string; else \c indeterminate. */
     TriBool strToTriBool( const C_Str & str );
 
     //@}
@@ -462,7 +462,7 @@ namespace zypp
 
     /** \overload A function is called on demand to compute each replacement value.
      */
-    std::string & replaceAllFun( std::string & str_r, const std::string & from_r, function<std::string()> to_r );
+    std::string & replaceAllFun( std::string & str_r, const std::string & from_r, const function<std::string()>& to_r );
 
     /** Enhance readability: insert gaps at regular distance
      * \code
@@ -884,7 +884,7 @@ namespace zypp
       /** Prefix lines by string computed by function taking line begin/end [std::string(const char*, const char*)]
        * Prints nothing for an empty string. Asserts a trainling '\n' on the last line.
        */
-      inline std::ostream & autoPrefix( std::ostream & str, const std::string & text_r, function<std::string(const char*, const char*)> fnc_r )
+      inline std::ostream & autoPrefix( std::ostream & str, const std::string & text_r, const function<std::string(const char*, const char*)>& fnc_r )
       {
         for ( const char * e = text_r.c_str(); *e; ++e )
         {
