@@ -14,6 +14,7 @@
 #include <string_view>
 #ifdef __cpp_lib_string_view
 
+#include <zypp/APIConfig.h>
 #include <zypp-core/base/String.h>
 #include <zypp-core/base/Regex.h>
 #include <zypp-core/base/Flags.h>
@@ -90,6 +91,14 @@ namespace zypp
     inline std::string_view trim( std::string_view str_r, TrimFlag trim_r )
     { return trim( std::move(str_r), blank, std::move(trim_r) ); }
 
+    /** Return whether \a str_r has prefix \a prefix_r. */
+    inline bool hasPrefix( std::string_view str_r, std::string_view prefix_r )
+    { return( ::strncmp( str_r.data(), prefix_r.data(), prefix_r.size() ) == 0 ); }
+
+    /** \overload Case insensitive */
+    inline bool hasPrefixCI( std::string_view str_r, std::string_view prefix_r  )
+    { return( ::strncasecmp( str_r.data(), prefix_r.data(), prefix_r.size()  ) == 0 ); }
+
     ///////////////////////////////////////////////////////////////////
     namespace detail
     {
@@ -171,8 +180,10 @@ namespace zypp
       unsigned _split( std::string_view line_r, std::string_view sep_r, Trim trim_r, WordConsumer && fnc_r );
 
       /** \ref splitRx working horse */
+      unsigned _splitRx(std::string_view line_r, const regex & rx_r, const WordConsumer& fnc_r );
+#if LEGACY(1722)
       unsigned _splitRx( const std::string & line_r, const regex & rx_r, WordConsumer && fnc_r );
-
+#endif
     }  // namespace detail
     ///////////////////////////////////////////////////////////////////
 
@@ -197,7 +208,7 @@ namespace zypp
      * \returns the number of words reported.
      */
     template <typename Callable = detail::WordConsumer>
-    unsigned splitRx( const std::string & line_r, const regex & rx_r, Callable && fnc_r = Callable() )
+    unsigned splitRx( std::string_view line_r, const regex & rx_r, Callable && fnc_r = Callable() )
     { return detail::_splitRx( line_r, rx_r, detail::wordConsumer( std::forward<Callable>(fnc_r) ) ); }
 
 
