@@ -413,6 +413,25 @@ namespace zyppng {
     return std::visit([]( const auto &s ) constexpr { return s.type(); }, _state );
   }
 
+  Socket::Ptr SocketPrivate::wrapSocket(int fd, int domain, int type, int protocol, Socket::SocketState state)
+  {
+    // from here on the Socket instance owns the fd, no need to manually close it
+    // in case of error
+    auto sptr = Socket::create( domain, type, protocol );
+    sptr->d_func()->_socket = fd;
+
+    // make sure the socket is non blocking
+    if ( !sptr->setBlocking( false ) ) {
+      DBG << "Failed to unblock socket." << std::endl;
+      return nullptr;
+    }
+
+    if( sptr->d_func()->transition( state ) )
+      return sptr;
+
+    return nullptr;
+  }
+
   ZYPP_IMPL_PRIVATE(Socket)
 
   Socket::Socket( int domain, int type, int protocol )
@@ -439,7 +458,7 @@ namespace zyppng {
     return Ptr( new Socket( domain, type, protocol ) );
   }
 
-  bool Socket::bind( std::shared_ptr<SockAddr> addr )
+  bool Socket::bind( const std::shared_ptr<SockAddr> &addr )
   {
     Z_D();
     if ( !addr || !d->initSocket() )
@@ -537,13 +556,13 @@ namespace zyppng {
       }
     }
 
-    return Socket::fromSocket( res, Socket::ConnectedState );
+    return SocketPrivate::wrapSocket( res, d->_domain, d->_type, d->_protocol, Socket::ConnectedState );
   }
 
   Socket::Ptr Socket::fromSocket( int fd, Socket::SocketState state )
   {
 
-    int domain;
+    int domain = 0;
     socklen_t optlen = sizeof(domain);
     int res = getsockopt( fd, SOL_SOCKET, SO_DOMAIN, &domain, &optlen );
     if ( res < 0 ) {
@@ -552,8 +571,8 @@ namespace zyppng {
       return nullptr;
     }
 
-    int protocol;
-    optlen = sizeof(domain);
+    int protocol = 0;
+    optlen = sizeof(protocol);
     res = getsockopt( fd, SOL_SOCKET, SO_PROTOCOL, &protocol, &optlen );
     if ( res < 0 ) {
       DBG << "Error querying socket protocol: " << strerr_cxx() << std::endl;
@@ -561,8 +580,8 @@ namespace zyppng {
       return nullptr;
     }
 
-    int type;
-    optlen = sizeof(domain);
+    int type = 0;
+    optlen = sizeof(type);
     res = getsockopt( fd, SOL_SOCKET, SO_TYPE, &type, &optlen );
     if ( res < 0 ) {
       DBG << "Error querying socket type: " << strerr_cxx() << std::endl;
@@ -570,21 +589,7 @@ namespace zyppng {
       return nullptr;
     }
 
-    // from here on the Socket instance owns the fd, no need to manually close it
-    // in case of error
-    auto sptr = Socket::create( domain, type, protocol );
-    sptr->d_func()->_socket = fd;
-
-    // make sure the socket is non blocking
-    if ( !sptr->setBlocking( false ) ) {
-      DBG << "Failed to unblock socket." << std::endl;
-      return nullptr;
-    }
-
-    if( sptr->d_func()->transition( state ) )
-      return sptr;
-
-    return nullptr;
+    return SocketPrivate::wrapSocket( fd, domain, type, protocol, state );
   }
 
   bool Socket::setBlocking( const bool set )
@@ -619,7 +624,7 @@ namespace zyppng {
     if ( !d->initSocket() )
       return false;
 
-    d->_targetAddr = addr;
+    d->_targetAddr = std::move(addr);
     if ( !d->transition( Socket::ConnectingState ) ) {
       abort();
       return false;
