@@ -57,6 +57,10 @@ NetworkRequestDispatcherPrivate::NetworkRequestDispatcherPrivate(  NetworkReques
   curl_multi_setopt( _multi, CURLMOPT_SOCKETFUNCTION, NetworkRequestDispatcherPrivate::static_socket_callback );
   curl_multi_setopt( _multi, CURLMOPT_SOCKETDATA, reinterpret_cast<void *>( this ) );
 
+  // disabled explicit pipelining since it breaks our tests on releases < 15.2
+  // we could consider enabling it starting with a specific CURL version
+  // curl_multi_setopt( _multi, CURLMOPT_PIPELINING, CURLPIPE_MULTIPLEX|CURLPIPE_HTTP1 );
+
   _timer->setSingleShot( true );
   _timer->connect( &Timer::sigExpired, *this, &NetworkRequestDispatcherPrivate::multiTimerTimout );
 }
@@ -130,7 +134,7 @@ int NetworkRequestDispatcherPrivate::socketCallback(CURL *easy, curl_socket_t s,
       return 0;
     } else {
       //a broken handle without anything assigned, also should never happen but make sure and clean it up
-      WAR_MEDIA << "Cleaning up unassigned  easy handle" << std::endl;
+      WAR << "Cleaning up unassigned  easy handle" << std::endl;
       curl_multi_remove_handle( _multi, easy );
       curl_easy_cleanup( easy );
       return 0;
@@ -207,30 +211,54 @@ void NetworkRequestDispatcherPrivate::handleMultiSocketAction(curl_socket_t nati
 
       void *privatePtr = nullptr;
       if ( curl_easy_getinfo( easy, CURLINFO_PRIVATE, &privatePtr ) != CURLE_OK ) {
-        WAR_MEDIA << "Unable to get CURLINFO_PRIVATE" << std::endl;
+        WAR << "Unable to get CURLINFO_PRIVATE" << std::endl;
         continue;
       }
 
       if ( !privatePtr ) {
         //broken easy handle not associated, should never happen but clean it up
-        WAR_MEDIA << "Cleaning up unassigned  easy handle" << std::endl;
+        WAR << "Cleaning up unassigned  easy handle" << std::endl;
         curl_multi_remove_handle( _multi, easy );
         curl_easy_cleanup( easy );
         continue;
       }
 
       NetworkRequestPrivate *request = reinterpret_cast<NetworkRequestPrivate *>( privatePtr );
+      request->dequeueNotify();
 
-      //trigger notification about file downloaded
-      NetworkRequestError e = NetworkRequestErrorPrivate::fromCurlError( *request->z_func(), res, request->errorMessage() );
-      setFinished( *request->z_func(), e );
+      if ( request->hasMoreWork() && ( res == CURLE_OK || request->canRecover() ) ) {
+        std::string errBuf = "Broken easy handle in request";
+        if ( !request->_easyHandle ) {
+          NetworkRequestError e = NetworkRequestErrorPrivate::customError ( NetworkRequestError::InternalError, std::move(errBuf) );
+          setFinished( *request->z_func(), e );
+          continue;
+        }
 
+        // remove the handle from multi to change options
+        curl_multi_remove_handle( _multi, request->_easyHandle );
+
+        errBuf = "Failed to reinitialize the request";
+        if ( !request->prepareToContinue ( errBuf ) ) {
+          NetworkRequestError e = NetworkRequestErrorPrivate::customError ( NetworkRequestError::InternalError, std::move(errBuf) );
+          setFinished( *request->z_func(), e );
+        } else {
+          // add the request back to the multi handle, it is not done
+          if ( !addRequestToMultiHandle( *request->z_func() ) )
+            continue;
+
+          request->aboutToStart( );
+        }
+      } else {
+        //trigger notification about file downloaded
+        NetworkRequestError e = NetworkRequestErrorPrivate::fromCurlError( *request->z_func(), res, request->errorMessage() );
+        setFinished( *request->z_func(), e );
+      }
       //attention request could be deleted from here on
     }
   }
 }
 
-void NetworkRequestDispatcherPrivate::cancelAll( NetworkRequestError result )
+void NetworkRequestDispatcherPrivate::cancelAll( const NetworkRequestError& result )
 {
   //prevent dequeuePending from filling up the runningDownloads again
   zypp::DtorReset lockReset( _locked );
@@ -294,6 +322,16 @@ void NetworkRequestDispatcherPrivate::setFinished( NetworkRequest &req, NetworkR
   dequeuePending();
 }
 
+bool NetworkRequestDispatcherPrivate::addRequestToMultiHandle(NetworkRequest &req)
+{
+  CURLMcode rc = curl_multi_add_handle( _multi, req.d_func()->_easyHandle );
+  if ( rc != 0 ) {
+    setFinished( req, NetworkRequestErrorPrivate::fromCurlMError( rc ) );
+    return false;
+  }
+  return true;
+}
+
 void NetworkRequestDispatcherPrivate::dequeuePending()
 {
   if ( !_isRunning || _locked )
@@ -313,11 +351,8 @@ void NetworkRequestDispatcherPrivate::dequeuePending()
       continue;
     }
 
-    CURLMcode rc = curl_multi_add_handle( _multi, req->d_func()->_easyHandle );
-    if ( rc != 0 ) {
-      setFinished( *req, NetworkRequestErrorPrivate::fromCurlMError( rc ) );
+    if ( !addRequestToMultiHandle( *req ) )
       continue;
-    }
 
     req->d_func()->aboutToStart();
     _sigDownloadStarted.emit( *z_func(), *req );
@@ -348,7 +383,7 @@ bool NetworkRequestDispatcher::supportsProtocol( const Url &url )
   // curl_info does not need any free (is static)
   if (curl_info->protocols)
   {
-    const char * const *proto;
+    const char * const *proto = nullptr;
     std::string        scheme( url.getScheme() );
     bool               found = false;
     for(proto=curl_info->protocols; !found && *proto; ++proto) {
@@ -365,6 +400,11 @@ void NetworkRequestDispatcher::setMaximumConcurrentConnections( const int maxCon
   d_func()->_maxConnections = maxConn;
 }
 
+int NetworkRequestDispatcher::maximumConcurrentConnections () const
+{
+  return d_func()->_maxConnections;
+}
+
 void NetworkRequestDispatcher::enqueue(const std::shared_ptr<NetworkRequest> &req )
 {
   if ( !req )
@@ -372,12 +412,12 @@ void NetworkRequestDispatcher::enqueue(const std::shared_ptr<NetworkRequest> &re
   Z_D();
 
   if ( std::find( d->_runningDownloads.begin(), d->_runningDownloads.end(), req ) != d->_runningDownloads.end() )  {
-    WAR_MEDIA << "Ignoring request to enqueue download " << req->url().asString() << " request is already running " << std::endl;
+    WAR << "Ignoring request to enqueue download " << req->url().asString() << " request is already running " << std::endl;
     return;
   }
 
   if ( std::find( d->_pendingDownloads.begin(), d->_pendingDownloads.end(), req ) != d->_pendingDownloads.end() ) {
-    WAR_MEDIA << "Ignoring request to enqueue download " << req->url().asString() << " request is already enqueued " << std::endl;
+    WAR << "Ignoring request to enqueue download " << req->url().asString() << " request is already enqueued " << std::endl;
     return;
   }
 
