@@ -15,6 +15,8 @@
 #include <zypp-core/Url.h>
 #include <zypp-core/base/PtrTypes.h>
 
+#include <utility>
+
 namespace zypp {
   namespace media {
 
@@ -33,8 +35,8 @@ public:
 
   AuthData(const Url & url);
 
-  AuthData(const std::string & username, const std::string & password)
-    : _username(username), _password(password), _lastChange(0)
+  AuthData(std::string  username, std::string  password)
+    : _username(std::move(username)), _password(std::move(password)), _lastChange(0)
   {}
 
   virtual ~AuthData() {};
@@ -61,6 +63,9 @@ public:
   time_t lastDatabaseUpdate () const;
   void setLastDatabaseUpdate ( time_t time );
 
+  const std::map<std::string, std::string> &extraValues() const;
+  std::map<std::string, std::string> &extraValues();
+
   virtual std::ostream & dumpOn( std::ostream & str ) const;
 
   virtual std::ostream & dumpAsIniOn( std::ostream & str ) const;
@@ -70,9 +75,10 @@ private:
   std::string _username;
   std::string _password;
   time_t _lastChange; //< timestamp of the last change to the database this credential is stored in
+  std::map<std::string, std::string> _extraValues;
 };
 
-typedef shared_ptr<AuthData> AuthData_Ptr;
+using AuthData_Ptr = shared_ptr<AuthData>;
 std::ostream & operator << (std::ostream & str, const AuthData & auth_data);
 
 ///////////////////////////////////////////////////////////////////
