@@ -23,6 +23,7 @@
 #include <zypp-core/base/Exception.h>
 #include <zypp-core/base/String.h>
 #include <zypp-core/base/Flags.h>
+#include <utility>
 #include <zypp-core/base/DefaultIntegral>
 #include <zypp-core/base/DtorReset>
 #include <zypp-core/base/Gettext.h>
@@ -109,12 +110,12 @@ namespace out
     struct ListLayoutInit : public ListLayout { ListLayoutInit() : ListLayout( singleline_, wrapline_, gaped_, indent_ ) {} };
   }
 
-  typedef detail::ListLayoutInit<true, false,false, 0U>	XmlListLayout;
-  typedef detail::ListLayoutInit<true, true, false, 0U>	DefaultListLayout;	///< one element per line, no indent
-  typedef detail::ListLayoutInit<true, true, true,  0U>	DefaultGapedListLayout;	///< one element per line, no indent, gaped
-  typedef detail::ListLayoutInit<true, true, false, 2U>	IndentedListLayout;	///< one element per line, indented
-  typedef detail::ListLayoutInit<true, true, true,  2U>	IndentedGapedListLayout;///< one element per line, indented, gaped
-  typedef detail::ListLayoutInit<false,true, false, 2U>	CompressedListLayout;	///< multiple elements per line, indented
+  using XmlListLayout = detail::ListLayoutInit<true, false, false, 0U>;
+  using DefaultListLayout = detail::ListLayoutInit<true, true, false, 0U>;	///< one element per line, no indent
+  using DefaultGapedListLayout = detail::ListLayoutInit<true, true, true, 0U>;	///< one element per line, no indent, gaped
+  using IndentedListLayout = detail::ListLayoutInit<true, true, false, 2U>;	///< one element per line, indented
+  using IndentedGapedListLayout = detail::ListLayoutInit<true, true, true, 2U>;///< one element per line, indented, gaped
+  using CompressedListLayout = detail::ListLayoutInit<false, true, false, 2U>;	///< multiple elements per line, indented
 
   /*!
    * \class TableLayout
@@ -125,7 +126,7 @@ namespace out
     template <class TFormater> struct Writer;
   };
 
-  typedef TableLayout	DefaultTableLayout;	///< Simple Table
+  using DefaultTableLayout = TableLayout;	///< Simple Table
 
   // Either specialize per Type or define a custom Formater:
 
@@ -170,7 +171,7 @@ namespace out
   ///////////////////////////////////////////////////////////////////
   struct ListFormater : public XmlFormater
   {
-    typedef DefaultListLayout	NormalLayout;		//< ListLayout for NORMAL lists
+    using NormalLayout = DefaultListLayout;		//< ListLayout for NORMAL lists
 
     template <class Tp>
     std::string listElement( const Tp & val_r ) const	//< NORMAL representation of list element
@@ -183,7 +184,7 @@ namespace out
   ///////////////////////////////////////////////////////////////////
   struct TableFormater : public XmlFormater
   {
-    typedef DefaultTableLayout	NormalLayout;		//< NORMAL layout as Table
+    using NormalLayout = DefaultTableLayout;		//< NORMAL layout as Table
 
     TableHeader header() const				//< TableHeader for TableRow representation
     { return asTableHeader<>(); }
@@ -201,7 +202,7 @@ namespace out
   template <class TFormater>
   struct XmlFormaterAdaptor
   {
-    typedef XmlListLayout	NormalLayout;		//< Layout as XML list
+    using NormalLayout = XmlListLayout;		//< Layout as XML list
 
     template <class Tp>
     std::string listElement( const Tp & val_r ) const	//< use TFormater::asXmlListElement
@@ -483,7 +484,7 @@ public:
   /// \endcode
   struct XmlNode : protected ParentOut
   {
-    typedef zypp::xmlout::Node::Attr Attr;
+    using Attr = zypp::xmlout::Node::Attr;
 
     /** Ctor taking nodename and attribute list. */
     XmlNode( Out & out_r, const std::string & name_r, const std::initializer_list<Attr> & attrs_r = {} )
@@ -495,11 +496,11 @@ public:
 
     /** Convenience ctor for one attribute pair */
     XmlNode( Out & out_r, const std::string & name_r, Attr attr_r )
-    : XmlNode( out_r, name_r, { attr_r } )
+    : XmlNode( out_r, name_r, { std::move(attr_r) } )
     {}
 
     /** Move ctor */
-    XmlNode( XmlNode && rhs ) : ParentOut( rhs ) { _node.swap( rhs._node ); }
+    XmlNode( XmlNode && rhs ) noexcept : ParentOut( rhs ) { _node.swap( rhs._node ); }
 
   private:
     zypp::scoped_ptr<zypp::xmlout::Node> _node;
@@ -515,7 +516,7 @@ public:
   { if ( typeXML() ) { zypp::xmlout::node( std::cout, name_r, attrs_r ); } }
   /** \overload for one attribute pair */
   void xmlNode( const std::string & name_r, XmlNode::Attr attr_r )
-  { xmlNode( name_r, { attr_r } ); }
+  { xmlNode( name_r, { std::move(attr_r) } ); }
 
   ///////////////////////////////////////////////////////////////////
   /// \class TitleNode
@@ -567,7 +568,7 @@ public:
   void gap() { if ( type() == TYPE_NORMAL ) std::cout << std::endl; }
 
   void printRichText( std::string text, unsigned indent_r = 0U )
-  { ztui::printRichText( std::cout, text, indent_r, termwidth() ); }
+  { ztui::printRichText( std::cout, std::move(text), indent_r, termwidth() ); }
 
 
   /** Less common Paragraph formats */
@@ -658,7 +659,7 @@ public:
       , _str( new std::ostringstream )
     {}
 
-    Info( Out::Info && rhs )
+    Info( Out::Info && rhs ) noexcept
       : ParentOut( rhs )
       , _str( std::move(rhs._str) )
     {}
@@ -997,9 +998,9 @@ public:
    * If non zero values for \a current_r or \a total_r are passed,
    * the label is prefixed by either "(#C)" or "(#C/#T)"
    */
-  ProgressBar( Out & out_r, NoStartBar, const std::string & progressId_r, const std::string & label_r, unsigned current_r = 0, unsigned total_r = 0 )
+  ProgressBar( Out & out_r, NoStartBar, std::string  progressId_r, const std::string & label_r, unsigned current_r = 0, unsigned total_r = 0 )
     : _out( out_r )
-    , _progressId( progressId_r )
+    , _progressId(std::move( progressId_r ))
   {
     if ( total_r )
       _labelPrefix = zypp::str::form( "(%*u/%u) ", numDigits( total_r ), current_r, total_r );
