@@ -25,7 +25,7 @@ namespace zypp
 { /////////////////////////////////////////////////////////////////
 
   class IdString;
-  typedef std::unordered_set<IdString> IdStringSet;
+  using IdStringSet = std::unordered_set<IdString>;
 
   ///////////////////////////////////////////////////////////////////
   //
@@ -42,7 +42,7 @@ namespace zypp
   class IdString : protected sat::detail::PoolMember
   {
     public:
-      typedef sat::detail::IdType IdType;
+      using IdType = sat::detail::IdType;
 
     public:
       /** Default ctor, empty string. */
@@ -102,6 +102,16 @@ namespace zypp
       explicit operator std::string() const
       { return asString(); }
 
+#ifdef __cpp_lib_string_view
+      /** As \c std::string_view */
+      std::string_view asStringView() const
+      { return { c_str(), size() }; }
+
+      /** Explicit conversion to \c std::string_view */
+      explicit operator std::string_view() const
+      { return asStringView(); }
+#endif
+
     public:
       /** Fast compare equal. */
       bool compareEQ( const IdString & rhs ) const
