@@ -16,14 +16,14 @@
 #include <set>
 #include <map>
 
-#include "zypp/base/Regex.h"
-#include "zypp/base/PtrTypes.h"
-#include "zypp/base/Function.h"
+#include <zypp/base/Regex.h>
+#include <zypp/base/PtrTypes.h>
+#include <zypp/base/Function.h>
 
-#include "zypp/sat/SolvIterMixin.h"
-#include "zypp/sat/LookupAttr.h"
-#include "zypp/base/StrMatcher.h"
-#include "zypp/sat/Pool.h"
+#include <zypp/sat/SolvIterMixin.h>
+#include <zypp/sat/LookupAttr.h>
+#include <zypp/base/StrMatcher.h>
+#include <zypp/sat/Pool.h>
 
 ///////////////////////////////////////////////////////////////////
 namespace zypp
@@ -90,15 +90,15 @@ namespace zypp
   class PoolQuery : public sat::SolvIterMixin<PoolQuery, detail::PoolQueryIterator>
   {
   public:
-    typedef std::set<ResKind>                               Kinds;
-    typedef std::set<std::string>                           StrContainer;
-    typedef std::map<sat::SolvAttr, StrContainer>           AttrRawStrMap;
+    using Kinds = std::set<ResKind>;
+    using StrContainer = std::set<std::string>;
+    using AttrRawStrMap = std::map<sat::SolvAttr, StrContainer>;
 
-    typedef detail::PoolQueryIterator                       const_iterator;
-    typedef unsigned int                                    size_type;
+    using const_iterator = detail::PoolQueryIterator;
+    using size_type = unsigned int;
 
   public:
-    typedef function<bool( const sat::Solvable & )> ProcessResolvable;
+    using ProcessResolvable = function<bool (const sat::Solvable &)>;
 
     PoolQuery();
     ~PoolQuery();
@@ -160,6 +160,14 @@ namespace zypp
      */
     void addRepo(const std::string &repoalias);
 
+    /** Set an optional comment string describing the purpose of the query.
+     * Stored and retrieved when serializing the query. E.g. as lock.
+     */
+    void setComment(const std::string & comment) const;
+#if LEGACY(1722)
+    void setComment(const std::string & comment);
+#endif
+
     /** Installed status filter setters. */
     //@{
 
@@ -392,6 +400,8 @@ namespace zypp
 
     const StrContainer & repos() const;
 
+    const std::string & comment() const;
+
     const Edition edition() const;
     const Rel editionRel() const;
 
@@ -514,10 +524,10 @@ namespace zypp
     , const sat::Solvable              // Reference
   >
   {
-      typedef std::vector<sat::LookupAttr::iterator> Matches;
+      using Matches = std::vector<sat::LookupAttr::iterator>;
     public:
-      typedef Matches::size_type size_type;
-      typedef Matches::const_iterator matches_iterator;
+      using size_type = Matches::size_type;
+      using matches_iterator = Matches::const_iterator;
     public:
       /** Default ctor is also \c end.*/
       PoolQueryIterator()
