@@ -27,6 +27,8 @@
 #include <zypp/repo/ServiceType.h>
 #include <zypp/ServiceInfo.h>
 #include <zypp/RepoStatus.h>
+#include <zypp/RepoManagerOptions.h>
+#include <utility>
 #include <zypp-core/ui/ProgressData>
 
 ///////////////////////////////////////////////////////////////////
@@ -37,7 +39,9 @@ namespace zypp
     * Parses \a repo_file and returns a list of \ref RepoInfo objects
     * corresponding to repositories found within the file.
     *
-    * \param repo_file Valid URL of the repo file.
+    * \param repo_file Valid URL of the repo file. The URL is subject to
+    * repo variable expansion.
+    *
     * \return found list<RepoInfo>
     *
     * \throws MediaException If the access to the url fails
@@ -46,58 +50,6 @@ namespace zypp
     */
    std::list<RepoInfo> readRepoFile(const Url & repo_file);
 
-  /**
-   * Repo manager settings.
-   * Settings default to ZYpp global settings.
-   */
-  struct RepoManagerOptions
-  {
-    /** Default ctor following \ref ZConfig global settings.
-     * If an optional \c root_r directory is given, all paths  will
-     * be prefixed accordingly.
-     * \code
-     *    root_r\repoCachePath
-     *          \repoRawCachePath
-     *          \repoSolvCachePath
-     *          \repoPackagesCachePath
-     *          \knownReposPath
-     * \endcode
-     */
-    RepoManagerOptions( const Pathname & root_r = Pathname() );
-
-    /** Test setup adjusting all paths to be located below one \c root_r directory.
-     * \code
-     *    root_r\          - repoCachePath
-     *          \raw       - repoRawCachePath
-     *          \solv      - repoSolvCachePath
-     *          \packages  - repoPackagesCachePath
-     *          \repos.d   - knownReposPath
-     * \endcode
-     */
-    static RepoManagerOptions makeTestSetup( const Pathname & root_r );
-
-    Pathname repoCachePath;
-    Pathname repoRawCachePath;
-    Pathname repoSolvCachePath;
-    Pathname repoPackagesCachePath;
-    Pathname knownReposPath;
-    Pathname knownServicesPath;
-    Pathname pluginsPath;
-    bool probe;
-    /**
-     * Target distro ID to be used when refreshing repo index services.
-     * Repositories not maching this ID will be skipped/removed.
-     *
-     * If empty, \ref Target::targetDistribution() will be used instead.
-     */
-    std::string servicesTargetDistro;
-
-    /** remembers root_r value for later use */
-    Pathname rootDir;
-  };
-
-
-
   /**
    * \short creates and provides information about known sources.
    *
@@ -111,17 +63,17 @@ namespace zypp
     struct Impl;
 
     /** ServiceInfo typedefs */
-    typedef std::set<ServiceInfo> ServiceSet;
-    typedef ServiceSet::const_iterator ServiceConstIterator;
-    typedef ServiceSet::size_type ServiceSizeType;
+    using ServiceSet = std::set<ServiceInfo>;
+    using ServiceConstIterator = ServiceSet::const_iterator;
+    using ServiceSizeType = ServiceSet::size_type;
 
     /** RepoInfo typedefs */
-    typedef std::set<RepoInfo> RepoSet;
-    typedef RepoSet::const_iterator RepoConstIterator;
-    typedef RepoSet::size_type RepoSizeType;
+    using RepoSet = std::set<RepoInfo>;
+    using RepoConstIterator = RepoSet::const_iterator;
+    using RepoSizeType = RepoSet::size_type;
 
   public:
-   RepoManager( const RepoManagerOptions &options = RepoManagerOptions() );
+   RepoManager( RepoManagerOptions options = RepoManagerOptions() );
    /** Dtor */
     ~RepoManager();
 
@@ -147,7 +99,7 @@ namespace zypp
     ZYPP_DECLARE_FLAGS(RefreshServiceFlags,RefreshServiceBit);
 
     /** Options tuning RefreshService */
-    typedef RefreshServiceFlags RefreshServiceOptions;
+    using RefreshServiceOptions = RefreshServiceFlags;
 
 
     /** \name Known repositories.
@@ -427,7 +379,7 @@ namespace zypp
 
    /**
     * \short Adds repositores from a repo file to the list of known repositories.
-    * \param url Url of the repo file
+    * \param url Url of the repo file. The URL is subject to repo variable expansion.
     *
     * \throws repo::RepoAlreadyExistsException If the repo clash some
     *         unique attribute like alias
@@ -634,6 +586,12 @@ namespace zypp
     void modifyService( const ServiceInfo & service )
     { modifyService( service.alias(), service ); }
 
+    /*!
+     * Checks for any of the given \a urls if there is no geoip data available, caches the results
+     * in the metadata cache for 24hrs. The given urls need to be configured as valid geoIP targets ( usually download.opensuse.org )
+     */
+    void refreshGeoIp ( const RepoInfo::url_set &urls );
+
   private:
     /**
      * Functor thats filter RepoInfo by service which it belongs to.
@@ -641,7 +599,7 @@ namespace zypp
     struct MatchServiceAlias
     {
       public:
-        MatchServiceAlias( const std::string & alias_ ) : alias(alias_) {}
+        MatchServiceAlias( std::string  alias_ ) : alias(std::move(alias_)) {}
         bool operator()( const RepoInfo & info ) const
         { return info.service() == alias; }
       private:
