@@ -62,17 +62,17 @@ namespace zypp
      * checked by the compiler.
      */
     //@{
-    typedef uint16_t FieldType;
-    typedef bit::BitField<FieldType> BitFieldType;
+    using FieldType = uint16_t;
+    using BitFieldType = bit::BitField<FieldType>;
     // Bit Ranges within FieldType defined by 1st bit and size:
-    typedef bit::Range<FieldType,0,                          1> StateField;
-    typedef bit::Range<FieldType,StateField::end,            2> ValidateField;
-    typedef bit::Range<FieldType,ValidateField::end,         2> TransactField;
-    typedef bit::Range<FieldType,TransactField::end,         2> TransactByField;
-    typedef bit::Range<FieldType,TransactByField::end,       2> TransactDetailField;
-    typedef bit::Range<FieldType,TransactDetailField::end,   1> LicenceConfirmedField;
-    typedef bit::Range<FieldType,LicenceConfirmedField::end, 4> WeakField;
-    typedef bit::Range<FieldType,WeakField::end,             1> UserLockQueryField; // internal
+    using StateField            = bit::Range<FieldType, 0                         , 1>;
+    using ValidateField         = bit::Range<FieldType, StateField::end           , 2>;
+    using TransactField         = bit::Range<FieldType, ValidateField::end        , 2>;
+    using TransactByField       = bit::Range<FieldType, TransactField::end        , 2>;
+    using TransactDetailField   = bit::Range<FieldType, TransactByField::end      , 2>;
+    using LicenceConfirmedField = bit::Range<FieldType, TransactDetailField::end  , 1>;
+    using WeakField             = bit::Range<FieldType, LicenceConfirmedField::end, 4>;
+    using UserLockQueryField    = bit::Range<FieldType, WeakField::end            , 1>; // internal
     // enlarge FieldType if more bits are needed. It's not yet
     // checked by the compiler.
     //@}
@@ -162,6 +162,11 @@ namespace zypp
     /** Dtor. */
     ~ResStatus();
 
+    ResStatus(const ResStatus &) = default;
+    ResStatus(ResStatus &&) noexcept = default;
+    ResStatus &operator=(const ResStatus &) = default;
+    ResStatus &operator=(ResStatus &&) noexcept = default;
+
     /** Debug helper returning the bitfield.
      * It's save to expose the bitfield, as it can't be used to
      * recreate a ResStatus. So it is not possible to bypass
@@ -328,22 +333,21 @@ namespace zypp
     { return isToBeUninstalled() && fieldValueIs<TransactDetailField>( SOFT_REMOVE ); }
 
   private:
-
-    /** \name Internal hard lock maintainance */
+    /** \name Internal hard lock maintenance */
     //@{
     friend struct resstatus::UserLockQueryManip;
 
-    bool isUserLockQueryMatch() const
-    { return fieldValueIs<UserLockQueryField>( USERLOCK_MATCH ); }
-
     void setUserLockQueryMatch( bool match_r )
     { fieldValueAssign<UserLockQueryField>( match_r ? USERLOCK_MATCH : USERLOCK_NOMATCH ); }
     //@}
+  public:
+    bool isUserLockQueryMatch() const
+    { return fieldValueIs<UserLockQueryField>( USERLOCK_MATCH ); }
 
   public:
 
     //------------------------------------------------------------------------
-    // get/set functions, returnig \c true if requested status change
+    // get/set functions, returning \c true if requested status change
     // was successful (i.e. leading to the desired transaction).
     // If a lower level (e.g.SOLVER) wants to transact, but it's
     // already set by a higher level, \c true should be returned.
@@ -382,7 +386,7 @@ namespace zypp
 
     /** Apply a lock (prevent transaction).
      * Currently by USER or APPL_HIGH only, but who knows...
-     * Set LOCKED from KEEP_STATE to be shure all transaction
+     * Set LOCKED from KEEP_STATE to be sure all transaction
      * details were reset properly.
     */
     bool setLock( bool toLock_r, TransactByValue causer_r )
@@ -428,7 +432,7 @@ namespace zypp
     /** Toggle between TRANSACT and KEEP_STATE.
      * LOCKED state means KEEP_STATE. But in contrary to KEEP_STATE,
      * LOCKED state is immutable for \a causer_r less than TransactByValue.
-     * KEEP_STATE may be canged by any \a causer_r.
+     * KEEP_STATE may be changed by any \a causer_r.
     */
     bool setTransact( bool toTansact_r, TransactByValue causer_r )
     {
@@ -643,7 +647,7 @@ namespace zypp
       return true;
     }
 
-    bool setStatus( ResStatus newStatus_r )
+    bool setStatus( const ResStatus& newStatus_r )
     {
       // State field is immutable!
       if ( _bitfield.value<StateField>() != newStatus_r._bitfield.value<StateField>() )
