@@ -48,7 +48,7 @@ namespace zypp
     /** Ctor */
     Resolver( const ResPool & pool );
     /** Dtor */
-    virtual ~Resolver();
+    ~Resolver() override;
 
     /**
      * Reset all solver flags to the systems default (e.g. from zypp.conf).
@@ -223,6 +223,38 @@ namespace zypp
     void setUpdateMode( bool yesno_r );
     bool updateMode() const;
 
+    /**
+     * Set whether to remove unused orphans in 'upgrade' mode.
+     *
+     * Orphaned packages are those which are neither provided by any repository
+     * not have update candidates within any repository. They often denoted as
+     * dropped or not-wanted. They are leftovers of previous distribution
+     * versions.
+     *
+     * \Note 3rd party .rpm packages simply installed are seen as orphaned and
+     * may be removed by dup. Collecting these packages in a directory and
+     * adding this directory as a (plaindir) repo turns them into wanted
+     * packages. They are kind of protected by being part of an enabled
+     * repository.
+     */
+    void setRemoveOrphaned( bool yesno_r );
+    bool removeOrphaned() const;
+
+    /**
+     * File weak remove jobs for unneeded installed packages.
+     *
+     * \Note There needs to be one (even if empty) solver run before
+     * unneeded installed packages are determined. So this does not
+     * contribute to the very first solver run.
+     *
+     * \Note In order to tailor the \c unneeded classification one needs
+     * to be able to control the \c autoinstalled property of a package.
+     * Only autoinstalled packages can be unneeded. So switching the
+     * autoinstalled property is the way to (potentially) add or (surely)
+     * remove a package from the unneeded set.
+     */
+    void setRemoveUnneeded( bool yesno_r );
+    bool removeUnneeded() const;
 
     /** \name  Solver flags (non DUP modes)
      * Default for all flags is \c false unless overwritten by zypp.conf.
