@@ -26,6 +26,7 @@
 ///////////////////////////////////////////////////////////////////
 namespace zypp
 { /////////////////////////////////////////////////////////////////
+  class VendorAttr;
   namespace target
   {
     class TargetImpl;
@@ -49,9 +50,9 @@ namespace zypp
   class Target : public base::ReferenceCounted, public base::NonCopyable
   {
   public:
-    typedef target::TargetImpl  Impl;
-    typedef intrusive_ptr<Impl> Impl_Ptr;
-    typedef std::list<PoolItem> PoolItemList;
+    using Impl = target::TargetImpl;
+    using Impl_Ptr = intrusive_ptr<Impl>;
+    using PoolItemList = std::list<PoolItem>;
 
   public:
 
@@ -71,7 +72,7 @@ namespace zypp
     void load();
 
     void reload();
-    
+
     /**
      * unload target resolvables from the
      * pool
@@ -136,7 +137,7 @@ namespace zypp
   public:
     /** \name Base product and registration.
      *
-     * Static methods herein allow to retrieve the values without explicitly
+     * Static methods herein allow one to retrieve the values without explicitly
      * initializing the \ref Target. They take a targets root directory as
      * argument. If an empty \ref Pathname is passed, an already existing
      * Targets root is used, otherwise \c "/" is assumed.
@@ -205,6 +206,19 @@ namespace zypp
     static std::string anonymousUniqueId( const Pathname & root_r );
     //@}
 
+  public:
+    /** \name Definition of vendor equivalence.
+     * \see \ref VendorAttr
+     */
+    //@{
+    /** The targets current vendor equivalence settings.
+     * Initialized from the targets /etc/zypp/vendors.d.
+     */
+    const VendorAttr & vendorAttr() const;
+    /** Assign new vendor equivalence settings to the target. */
+    void vendorAttr( VendorAttr vendorAttr_r );
+    //@}
+
   public:
     /** Ctor. If \c doRebuild_r is \c true, an already existing
      * database is rebuilt (rpm --rebuilddb ).
@@ -218,7 +232,7 @@ namespace zypp
   private:
     friend std::ostream & operator<<( std::ostream & str, const Target & obj );
     /** Stream output. */
-    std::ostream & dumpOn( std::ostream & str ) const;
+    std::ostream & dumpOn( std::ostream & str ) const override;
 
   private:
     /** Direct access to Impl. */
