@@ -81,6 +81,11 @@ class VendorAttr
     /** Dtor */
     ~VendorAttr();
 
+    VendorAttr(const VendorAttr &) = default;
+    VendorAttr(VendorAttr &&) noexcept = default;
+    VendorAttr &operator=(const VendorAttr &) = default;
+    VendorAttr &operator=(VendorAttr &&) noexcept = default;
+
     /**
      * Adding new equivalent vendors described in a directory
      **/
@@ -100,7 +105,7 @@ class VendorAttr
 #endif
 
     /** Preferred type to pass equivalent vendor strings. */
-    typedef std::vector<std::string> VendorList;
+    using VendorList = std::vector<std::string>;
 
     /**
      * Adding new equivalent vendor strings container.
@@ -116,7 +121,7 @@ class VendorAttr
     {
       VendorList tmp;
       for ( const auto & el : container_r )
-	tmp.push_back( std::string(el) );
+        tmp.push_back( std::string(el) );
       _addVendorList( std::move(tmp) );
     }
     /** \overload from std::initializer_list */
@@ -125,7 +130,7 @@ class VendorAttr
     {
       VendorList tmp;
       for ( const auto & el : container_r )
-	tmp.push_back( std::string(el) );
+        tmp.push_back( std::string(el) );
       _addVendorList( std::move(tmp) );
     }
 
@@ -142,6 +147,21 @@ class VendorAttr
     /** \overload using \ref PoolItem */
     bool equivalent( const PoolItem & lVendor, const PoolItem & rVendor ) const;
 
+    /** Like \ref equivalent but always unifies suse and openSUSE vendor */
+    bool relaxedEquivalent( const Vendor & lVendor, const Vendor & rVendor ) const;
+    /** \overload using \ref IdStrings */
+    bool relaxedEquivalent( IdString lVendor, IdString rVendor ) const;
+    /** \overload using \ref sat::Solvable */
+    bool relaxedEquivalent( sat::Solvable lVendor, sat::Solvable rVendor ) const;
+    /** \overload using \ref PoolItem */
+    bool relaxedEquivalent( const PoolItem & lVendor, const PoolItem & rVendor ) const;
+
+  public:
+    /** Call \a fnc_r for each equivalent vendor list (return \c false to break).
+     * \return The number of calls to \a fnc_r.
+     */
+    unsigned foreachVendorList( std::function<bool(VendorList)> fnc_r ) const;
+
   public:
     class Impl;                 ///< Implementation class.
     RWCOW_pointer<Impl> _pimpl; ///< Pointer to implementation.
