@@ -223,6 +223,28 @@ namespace zypp
        */
       Pathname needrebootPath() const;
 
+      /**
+       * Enables or disables the use of the geoip feature of download.opensuse.org
+       */
+      void setGeoipEnabled( bool enable = true );
+
+      /**
+       * Returns true if zypp should use the geoip feature of download.opensuse.org
+       */
+      bool geoipEnabled () const;
+
+      /**
+       * Path where the geoip caches are kept (/var/cache/zypp/geoip)
+       */
+      Pathname geoipCachePath() const;
+
+      /**
+       * All hostnames we want to rewrite using the geoip feature. The \ref RepoManager
+       * will try to query each hostname via: https://hostname/geoip to receive a redirection
+       * target for requests to the given hostname. The geoip targets are cached in \ref geoipCachePath.
+       */
+      const std::vector<std::string> geoipHostnames () const;
+
       /**
        * Path containing custom repo variable definitions (configPath()/vars.d).
        * \see \ref zypp::repo::RepoVarExpand Repo variable expander
@@ -548,12 +570,19 @@ namespace zypp
 
     public:
       class Impl;
+
+      ZConfig(const ZConfig &) = delete;
+      ZConfig(ZConfig &&) = delete;
+      ZConfig &operator=(const ZConfig &) = delete;
+      ZConfig &operator=(ZConfig &&) = delete;
+
       /** Dtor */
       ~ZConfig();
       void notifyTargetChanged();  ///< internal
 
   private:
       friend class RepoManager;
+      friend class RepoManagerBaseImpl;
       /** The builtin config file value. */
       Pathname builtinRepoCachePath() const;
       /** The builtin config file value. */
