@@ -14,7 +14,7 @@
 
 #include <zypp/base/EnumClass.h>
 #include <zypp/Callback.h>
-#include <zypp/UserData.h>
+#include <zypp-core/UserData.h>
 #include <zypp/Resolvable.h>
 #include <zypp/RepoInfo.h>
 #include <zypp/Pathname.h>
@@ -59,13 +59,17 @@ namespace zypp
   struct ProgressReportAdaptor
   {
 
+    ProgressReportAdaptor( callback::SendReport<ProgressReport> &report )
+      : _report(report)
+      , _first(true)
+    {}
+
     ProgressReportAdaptor( const ProgressData::ReceiverFnc &fnc,
                            callback::SendReport<ProgressReport> &report )
       : _fnc(fnc)
       , _report(report)
       , _first(true)
-    {
-    }
+    {}
 
     bool operator()( const ProgressData &progress )
     {
@@ -698,6 +702,7 @@ namespace zypp
             case loglevel::msg:  return "";
             case loglevel::dbg:  return "D: ";
           }
+          return "";
         }
       };
 
