@@ -32,6 +32,7 @@ extern "C"
 #include <boost/interprocess/sync/file_lock.hpp>
 #include <boost/interprocess/sync/scoped_lock.hpp>
 #include <boost/interprocess/sync/sharable_lock.hpp>
+#include <utility>
 
 #include <iostream>
 
@@ -104,15 +105,17 @@ namespace zypp
   class ZYppGlobalLock
   {
   public:
-    ZYppGlobalLock( Pathname &&lFilePath )
-      : _zyppLockFilePath( std::move(lFilePath) )
-    , _zyppLockFile( NULL )
-    , _lockerPid( 0 )
-    , _cleanLock( false )
-    {
+    ZYppGlobalLock(Pathname &&lFilePath)
+      : _zyppLockFilePath(std::move(lFilePath)), _zyppLockFile(NULL),
+        _lockerPid(0), _cleanLock(false) {
       filesystem::assert_dir(_zyppLockFilePath.dirname() );
     }
 
+    ZYppGlobalLock(const ZYppGlobalLock &) = delete;
+    ZYppGlobalLock(ZYppGlobalLock &&) = delete;
+    ZYppGlobalLock &operator=(const ZYppGlobalLock &) = delete;
+    ZYppGlobalLock &operator=(ZYppGlobalLock &&) = delete;
+
     ~ZYppGlobalLock()
     {
         if ( _cleanLock )
@@ -150,7 +153,7 @@ namespace zypp
     bool	_cleanLock;
 
   private:
-    typedef shared_ptr<void> ScopedGuard;
+    using ScopedGuard = shared_ptr<void>;
 
     /** Exception safe access to the lockfile.
      * \code
@@ -343,10 +346,10 @@ namespace zypp
   //
   ///////////////////////////////////////////////////////////////////
 
-  ZYppFactoryException::ZYppFactoryException( const std::string & msg_r, pid_t lockerPid_r, const std::string & lockerName_r )
-    : Exception( msg_r )
+  ZYppFactoryException::ZYppFactoryException( std::string msg_r, pid_t lockerPid_r, std::string lockerName_r )
+    : Exception( std::move(msg_r) )
     , _lockerPid( lockerPid_r )
-    , _lockerName( lockerName_r )
+    , _lockerName(std::move( lockerName_r ))
   {}
 
   ZYppFactoryException::~ZYppFactoryException() throw ()
