@@ -52,8 +52,8 @@ class MediaHandler {
     friend std::ostream & operator<<( std::ostream & str, const MediaHandler & obj );
 
     public:
-        typedef shared_ptr<MediaHandler> Ptr;
-        typedef shared_ptr<const MediaHandler> constPtr;
+        using Ptr = shared_ptr<MediaHandler>;
+        using constPtr = shared_ptr<const MediaHandler>;
 
         static bool setAttachPrefix(const Pathname &attach_prefix);
 
@@ -466,9 +466,9 @@ class MediaHandler {
          * On any error, the attach_point is set to an empty Pathname,
          * which should lead to E_bad_attachpoint.
          **/
-        MediaHandler ( const Url&       url_r,
+        MediaHandler ( Url        url_r,
                        const Pathname & attach_point_r,
-                       const Pathname & urlpath_below_attachpoint_r,
+                       Pathname  urlpath_below_attachpoint_r,
                        const bool       does_download_r );
 
         /**
@@ -580,7 +580,7 @@ class MediaHandler {
          * \throws MediaException
          *
          **/
-        void provideFileCopy( const OnMediaLocation &srcFile, Pathname targetFilename ) const;
+        void provideFileCopy( const OnMediaLocation &srcFile, const Pathname& targetFilename ) const;
 
         /**
          * Use concrete handler to provide directory denoted
@@ -591,7 +591,7 @@ class MediaHandler {
          * \throws MediaException
          *
          **/
-        void provideDir( Pathname dirname ) const;
+        void provideDir( const Pathname& dirname ) const;
 
         /**
          * Use concrete handler to provide directory tree denoted
@@ -602,7 +602,7 @@ class MediaHandler {
          * \throws MediaException
          *
          **/
-        void provideDirTree( Pathname dirname ) const;
+        void provideDirTree( const Pathname& dirname ) const;
 
         /**
          * Remove filename below localRoot IFF handler downloads files
@@ -634,7 +634,7 @@ class MediaHandler {
          * \throws MediaException
          *
          **/
-        void releasePath( Pathname pathname ) const;
+        void releasePath( const Pathname& pathname ) const;
 
     public:
 
