@@ -29,7 +29,7 @@ namespace zypp::media
 {
   class MediaHandler;
 
-  typedef unsigned int  MediaNr;
+  using MediaNr = unsigned int;
 
 
   ///////////////////////////////////////////////////////////////////
@@ -104,7 +104,7 @@ namespace zypp::media
   /**
    * A shared reference to the MediaVerifier implementation.
    */
-  typedef zypp::RW_pointer<MediaVerifierBase> MediaVerifierRef;
+  using MediaVerifierRef = zypp::RW_pointer<MediaVerifierBase>;
 
 
   ///////////////////////////////////////////////////////////////////
@@ -619,7 +619,7 @@ namespace zypp::media
      * to a server like FTP. After calling disconnect() the media
      * object (attach point) is still valid and files are present.
      *
-     * But after calling disconnect() it's not possible to call
+     * But after calling disconnect(), it's not possible to call
      * fetch more data using the provideFile() or provideDir()
      * functions anymore.
      *
