@@ -13,6 +13,7 @@
 #define ZYPP_SAT_LOOKUPATTR_H
 
 #include <iosfwd>
+#include <utility>
 
 #include <zypp/base/PtrTypes.h>
 #include <zypp-core/base/DefaultIntegral>
@@ -107,10 +108,10 @@ namespace zypp
     class LookupAttr
     {
       public:
-        typedef MatchException Exception;
+        using Exception = MatchException;
 
       public:
-        typedef unsigned size_type;
+        using size_type = unsigned int;
 
         /** Specify the where to look for the attribule. */
         enum Location {
@@ -122,6 +123,11 @@ namespace zypp
         /** Default ctor finds nothing. */
         LookupAttr();
 
+        LookupAttr(const LookupAttr &) = default;
+        LookupAttr(LookupAttr &&) noexcept = default;
+        LookupAttr &operator=(const LookupAttr &) = default;
+        LookupAttr &operator=(LookupAttr &&) noexcept = default;
+
         /** Lookup \ref SolvAttr in \ref Pool (all repositories). */
         explicit LookupAttr( SolvAttr attr_r, Location = SOLV_ATTR );
         /** \overload SolvAttr within sub-structure \a parent_r. */
@@ -262,7 +268,7 @@ namespace zypp
         {}
         /** \copydoc LookupAttr::LookupAttr(SolvAttr) */
         explicit LookupRepoAttr( SolvAttr attr_r )
-        : LookupAttr( attr_r, REPO_ATTR )
+        : LookupAttr( std::move(attr_r), REPO_ATTR )
         {}
         /** \copydoc LookupAttr::LookupAttr(SolvAttr,Repository) */
         explicit LookupRepoAttr( SolvAttr attr_r, Repository repo_r );
@@ -298,14 +304,14 @@ namespace zypp
           {}
           /** Initializes */
           DIWrap( RepoIdType repoId_r, SolvableIdType solvId_r, IdType attrId_r,
-                  const std::string & mstring_r = std::string(), int flags_r = 0 );
+                  std::string  mstring_r = std::string(), int flags_r = 0 );
           /** \overload to catch \c NULL \a mstring_r. */
           DIWrap( RepoIdType repoId_r, SolvableIdType solvId_r, IdType attrId_r,
                   const char * mstring_r, int flags_r = 0 );
           DIWrap( const DIWrap & rhs );
           ~DIWrap();
         public:
-          void swap( DIWrap & rhs )
+          void swap( DIWrap & rhs ) noexcept
           {
             if ( &rhs != this ) // prevent self assign!
             {
@@ -432,9 +438,9 @@ namespace zypp
          *
          * \note Unfortunately the underlying libsolv dataiterator as returned
          * by \ref subBegin and \ref subFind loses some context when being created.
-         * Thus it's not possible to invoke \ref subBegin and \ref subFind on an
+         * Thus, it's not possible to invoke \ref subBegin and \ref subFind on an
          * iterator that was previously returned by one of those methods. The result
-         * will be an \c end iterator. For the same reason it is not possible for an
+         * will be an \c end iterator. For the same reason, it is not possible for an
          * iterator to leave the sub-structure again.
          *
          * \code
@@ -476,7 +482,7 @@ namespace zypp
           * If \ref sat::SolvAttr::allAttr is passed, \ref subBegin is returned.
           * \see \ref solvAttrSubEntry
          */
-        iterator subFind( SolvAttr attr_r ) const;
+        iterator subFind( const SolvAttr& attr_r ) const;
         /** \overload Extending the current attribute name with by \c ":attrname_r".
          *
          * This assumes a sub-structur \c "update:reference" has attributes
@@ -543,7 +549,7 @@ namespace zypp
       public:
         /**
          * C-tor taking over ownership of the passed \c detail::CDataiterator
-         * and doing it's first iteration (::dataiterator_step)
+         * and doing its first iteration (::dataiterator_step)
          */
         iterator( detail::DIWrap & dip_r );
 
