@@ -53,7 +53,7 @@ namespace zypp
     class Solvable : protected detail::PoolMember
     {
     public:
-      typedef sat::detail::SolvableIdType IdType;
+      using IdType = sat::detail::SolvableIdType;
 
       static const IdString retractedToken;	///< Indicator provides `retracted-patch-package()`
       static const IdString ptfMasterToken;	///< Indicator provides `ptf()`
@@ -65,6 +65,11 @@ namespace zypp
       : _id( detail::noSolvableId )
       {}
 
+      Solvable(const Solvable &) = default;
+      Solvable(Solvable &&) noexcept = default;
+      Solvable &operator=(const Solvable &) = default;
+      Solvable &operator=(Solvable &&) noexcept = default;
+
       /** \ref PoolImpl ctor. */
       explicit Solvable( IdType id_r )
       : _id( id_r )
@@ -501,10 +506,11 @@ namespace zypp
     namespace detail
     {
       ///////////////////////////////////////////////////////////////////
-      //
-      //	CLASS NAME : SolvableIterator
-      //
-      /** */
+      /// \class SolvableIterator
+      /// \brief Iterate over valid Solvables in the pool.
+      /// If the Solvable passed to the ctor is not valid, advance
+      /// to the next valid solvable (or Solvable::noSolvable if the
+      /// end is reached,
       class SolvableIterator : public boost::iterator_adaptor<
           SolvableIterator                   // Derived
           , CSolvable*                       // Base
@@ -515,16 +521,16 @@ namespace zypp
       {
         public:
           SolvableIterator()
-          : SolvableIterator::iterator_adaptor_( 0 )
+          : SolvableIterator::iterator_adaptor_( nullptr )
           {}
 
           explicit SolvableIterator( const Solvable & val_r )
-          : SolvableIterator::iterator_adaptor_( 0 )
-          { assignVal( val_r ); }
+          : SolvableIterator::iterator_adaptor_( nullptr )
+          { initialAssignVal( val_r ); }
 
           explicit SolvableIterator( SolvableIdType id_r )
-          : SolvableIterator::iterator_adaptor_( 0 )
-          { assignVal( Solvable( id_r ) ); }
+          : SolvableIterator::iterator_adaptor_( nullptr )
+          { initialAssignVal( Solvable(id_r) ); }
 
         private:
           friend class boost::iterator_core_access;
@@ -536,6 +542,9 @@ namespace zypp
           { assignVal( _val.nextInPool() ); }
 
         private:
+          void initialAssignVal( const Solvable & val_r )
+          { assignVal( val_r ? val_r : val_r.nextInPool() ); }
+
           void assignVal( const Solvable & val_r )
           { _val = val_r; base_reference() = _val.get(); }
 
@@ -556,7 +565,7 @@ namespace zypp
      */
     struct asSolvable
     {
-      typedef Solvable result_type;
+      using result_type = Solvable;
 
       Solvable operator()( const Solvable & solv_r ) const
       { return solv_r; }
