@@ -80,9 +80,7 @@ class Resolver : private base::NonCopyable
     bool _upgradeMode:1;              // Resolver has been called with doUpgrade
     bool _updateMode:1;               // Resolver has been called with doUpdate
     bool _verifying:1;                // The system will be checked
-    bool _onlyRequires:1;             // do install required resolvables only
     bool _solveSrcPackages:1;         // whether to generate solver jobs for selected source packges.
-    bool _cleandepsOnRemove:1;        // whether removing a package should also remove no longer needed requirements
     bool _ignoreAlreadyRecommended:1; // ignore recommended packages that have already been recommended by the installed packages
     //@}
 
@@ -128,7 +126,7 @@ class Resolver : private base::NonCopyable
 
   public:
 
-    Resolver( const ResPool & pool );
+    Resolver( ResPool  pool );
     virtual ~Resolver();
 
     // ---------------------------------- I/O
@@ -165,8 +163,8 @@ class Resolver : private base::NonCopyable
     void addExtraConflict( const Capability & capability );
     void removeExtraConflict( const Capability & capability );
 
-    void removeQueueItem( SolverQueueItem_Ptr item );
-    void addQueueItem( SolverQueueItem_Ptr item );
+    void removeQueueItem( const SolverQueueItem_Ptr& item );
+    void addQueueItem( const SolverQueueItem_Ptr& item );
 
     CapabilitySet extraRequires() const		{ return _extra_requires; }
     CapabilitySet extraConflicts() const	{ return _extra_conflicts; }
@@ -199,6 +197,12 @@ class Resolver : private base::NonCopyable
     void setSolveSrcPackages( TriBool state_r )	{ _solveSrcPackages = indeterminate(state_r) ? false : bool(state_r); }
     //@}
 
+    void setRemoveOrphaned( bool yesno_r );
+    bool removeOrphaned() const;
+
+    void setRemoveUnneeded( bool yesno_r );
+    bool removeUnneeded() const;
+
     void setFocus( ResolverFocus focus_r );
     ResolverFocus focus() const;
 
