@@ -13,6 +13,7 @@
 #define ZYPP_UI_SELECTABLE_H
 
 #include <iosfwd>
+#include <utility>
 
 #include <zypp/base/ReferenceCounted.h>
 #include <zypp/base/NonCopyable.h>
@@ -54,18 +55,18 @@ namespace zypp
       friend std::ostream & dumpOn( std::ostream & str, const Selectable & obj );
 
     public:
-      typedef intrusive_ptr<Selectable>        Ptr;
-      typedef intrusive_ptr<const Selectable>  constPtr;
+      using Ptr = intrusive_ptr<Selectable>;
+      using constPtr = intrusive_ptr<const Selectable>;
 
       /** Iterates over ResObject::constPtr */
-      typedef SelectableTraits::available_iterator      available_iterator;
-      typedef SelectableTraits::available_size_type     available_size_type;
+      using available_iterator = SelectableTraits::available_iterator;
+      using available_size_type = SelectableTraits::available_size_type;
 
-      typedef SelectableTraits::installed_iterator      installed_iterator;
-      typedef SelectableTraits::installed_size_type     installed_size_type;
+      using installed_iterator = SelectableTraits::installed_iterator;
+      using installed_size_type = SelectableTraits::installed_size_type;
 
-      typedef SelectableTraits::picklist_iterator	picklist_iterator;
-      typedef SelectableTraits::picklist_size_type	picklist_size_type;
+      using picklist_iterator = SelectableTraits::picklist_iterator;
+      using picklist_size_type = SelectableTraits::picklist_size_type;
 
     public:
       /** \name Static ctor substitues picking the item from the pool.
@@ -80,13 +81,13 @@ namespace zypp
       /** Get the \ref Selctable */
       static Ptr get( const pool::ByIdent & ident_r );
 
-      /** Get the \ref Selctable by it's \c sat-identifyer. */
+      /** Get the \ref Selctable by its \c sat-identifier. */
       static Ptr get( IdString ident_r )
       { return get( pool::ByIdent( ident_r ) ); }
 
       /** Get the \ref Selctable by \c kind and \c name. */
       static Ptr get( ResKind kind_r, const std::string & name_r )
-      { return get( pool::ByIdent( kind_r, name_r ) ); }
+      { return get( pool::ByIdent( std::move(kind_r), name_r ) ); }
 
       /** Get the \c Package \ref Selctable by \c name. */
       static Ptr get( const std::string & name_r )
@@ -108,7 +109,7 @@ namespace zypp
     public:
       /** The identifier.
        * This is the solvables \ref name, \b except for packages and
-       * source packes, prefixed by it's \ref kind.
+       * source packes, prefixed by its \ref kind.
        * \see \ref sat::Solvable.
        */
       IdString ident() const;
@@ -142,7 +143,8 @@ namespace zypp
        * In contrary to \ref candidateObj, this may return no item even if
        * there are available objects. This simply means the best object is
        * already installed, and all available objects violate at least one
-       * update policy.
+       * update policy. Or all available objects are blacklisted (e.g. a PTF)
+       * in which there does not need to be an installed item either.
        * \note Avoids to return blacklisted items.
        */
       PoolItem updateCandidateObj() const;
@@ -224,11 +226,11 @@ namespace zypp
        */
       PoolItem setCandidate( const PoolItem & newCandidate_r, ResStatus::TransactByValue causer_r = ResStatus::USER );
       /** \overload */
-      PoolItem setCandidate( ResObject::constPtr newCandidate_r, ResStatus::TransactByValue causer_r = ResStatus::USER );
+      PoolItem setCandidate( const ResObject::constPtr& newCandidate_r, ResStatus::TransactByValue causer_r = ResStatus::USER );
 
       /** Arrange the specified candidate (out of available objects) to be on system after commit.
        * If the specified candidate is not already installed (\ref identicalInstalled),
-       * and the \a causer_r has sufficient permisssion, then \a newCandidate_r is set as the new
+       * and the \a causer_r has sufficient permission, then \a newCandidate_r is set as the new
        * candidate (\ref setCandidate) and selected for installation.
        * \returns \c True if \a newCandidate_r is already installed or successfully selected for installation.
        */
@@ -241,6 +243,12 @@ namespace zypp
        */
       PoolItem theObj() const;
 
+      /** The name(s) of the successor package if \ref vendorSupport is \ref VendorSupportSuperseded.
+       * It returns the value for the newest candidate.
+       * \see \ref Package::supersededBy
+       */
+      std::vector<std::string> supersededBy() const;
+
       ////////////////////////////////////////////////////////////////////////
 
       /** \name Available objects iterators.
@@ -553,12 +561,12 @@ namespace zypp
     public:
       /** Implementation  */
       struct Impl;
-      typedef shared_ptr<Impl> Impl_Ptr;
+      using Impl_Ptr = shared_ptr<Impl>;
       /** Default ctor */
       Selectable( Impl_Ptr pimpl_r );
     private:
       /** Dtor */
-      ~Selectable();
+      ~Selectable() override;
     private:
       /** Pointer to implementation */
       RW_pointer<Impl> _pimpl;
@@ -577,7 +585,7 @@ namespace zypp
      */
     struct asSelectable
     {
-      typedef Selectable_Ptr result_type;
+      using result_type = Selectable_Ptr;
 
       Selectable_Ptr operator()( const sat::Solvable & solv_r ) const;
 
